---
title: Examples Overview
menuTitle: Overview
permalink: /examples
category: Examples & Tutorials
redirect_from:
  - /tutorials
---

Below you can find tutorials to help you get started with Cube.js.

If you're already building something with Cube, please explore [recipes](/recipes) —
short, self-contained, and runnable solutions to popular use cases.

## Tutorials

These tutorials are great places to start learning Cube.js:

- [Cube.js, the Open Source Dashboard Framework: Ultimate Guide](https://cube.dev/blog/cubejs-open-source-dashboard-framework-ultimate-guide)
  — launch an API with Cube.js and build a dashboard with React

- [Building MongoDB Dashboard using Node.js](https://cube.dev/blog/building-mongodb-dashboard-using-node.js) —
  learn how to use MongoDB Connector for BI to connect Cube.js to MongoDB

- [React Dashboard: an Ultimate Guide](https://react-dashboard.cube.dev) — learn
  how to build a dynamic dashboard with React, GraphQL, and Cube.js

- [React query builder](https://cube.dev/blog/react-query-builder-with-cubejs)
  and [Vue query builder](https://cube.dev/blog/vue-query-builder-with-cubejs/)
  — learn how to use Query Builder components for React and Vue to build
  customizable query interfaces

The following tutorials cover advanced concepts of Cube.js:

- [Pre-Aggregations Tutorial](https://cube.dev/blog/high-performance-data-analytics-with-cubejs-pre-aggregations/) —
  learn about pre-aggregations, one of the most powerful Cube.js features that
  significantly speed up the performance of your applications such as dashboards
  and reports

- _Building an Open Source Mixpanel Alternative_ — a two-part series on building
  a production-ready application with Cube.js:
  [Part 1: Collecting and Displaying Events](https://cube.dev/blog/building-an-open-source-mixpanel-alternative-1),
  [Part 2: Conversion Funnels ](https://cube.dev/blog/building-open-source-mixpanel-alternative-2/)

### <--{"id" : "Tutorials"}--> Features

Learn more about prominent features of Cube.js:

| Feature                                                                                 | Story                                                                                                                | Demo                                              |
| :-------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------ |
| [Drill downs](https://cube.dev/docs/schema/fundamentals/additional-concepts#drilldowns) | [Introducing a drill down table API](https://cube.dev/blog/introducing-a-drill-down-table-api-in-cubejs/)            | [Demo](https://drill-downs-demo.cube.dev)         |
| [Compare date range](https://cube.dev/docs/query-format#time-dimensions-format)         | [Comparing data over different time periods](https://cube.dev/blog/comparing-data-over-different-time-periods/)      | [Demo](https://compare-date-range-demo.cube.dev)  |
| [Data blending](https://cube.dev/docs/recipes/data-blending)                            | [Introducing data blending API](https://cube.dev/blog/introducing-data-blending-api/)                                | [Demo](https://data-blending-demo.cube.dev)       |
| [Real-time data fetch](https://cube.dev/docs/real-time-data-fetch)                      | [Real-time dashboard guide](https://real-time-dashboard.cube.dev)                                                    | [Demo](https://real-time-dashboard-demo.cube.dev) |
| [Dynamic schema creation](https://cube.dev/docs/dynamic-schema-creation)                | [Using asyncModule to generate schemas](https://github.com/cube-js/cube.js/tree/master/examples/async-module-simple) | —                                                 |
| [Authentication](https://cube.dev/docs/security#using-json-web-key-sets-jwks)           | [Auth0 integration](https://github.com/cube-js/cube.js/tree/master/examples/auth0)                                   | —                                                 |
| [Authentication](https://cube.dev/docs/security#using-json-web-key-sets-jwks)           | [AWS Cognito integration](https://github.com/cube-js/cube.js/tree/master/examples/cognito)                           | —                                                 |

### <--{"id" : "Tutorials"}--> Front-end integrations

Explore how to integrate Cube.js with data visualization tools:

| Tool                                                                   | Tutorial                                                                                                                 | Demo                                                                                    |
| :--------------------------------------------------------------------- | :----------------------------------------------------------------------------------------------------------------------- | :-------------------------------------------------------------------------------------- |
| 📈 [D3.js](https://awesome.cube.dev/tools/d3)                          | [D3 dashboard tutorial](https://d3-dashboard.cube.dev)                                                                   | [Demo](https://d3-dashboard-demo.cube.dev)                                              |
| 📈 [Google Charts](https://awesome.cube.dev/tools/google-charts)       | [Google Charts dashboard](https://cube.dev/blog/google-charts-dashboard)                                                 | [Demo](https://google-charts-dashboard-demo.cube.dev)                                   |
| 📈 [Highcharts](https://awesome.cube.dev/tools/highcharts)             | [React Highcharts example](https://cube.dev/blog/react-highcharts-example/)                                              | [Demo](https://highcharts-demo.cube.dev)                                                |
| 📈 [Material UI](https://awesome.cube.dev/tools/material-ui-data-grid) | [Material UI Dashboard with React](https://material-ui-dashboard.cube.dev)                                               | [Demo](https://material-ui-dashboard-demo.cube.dev)                                     |
| 📈 [Material UI](https://awesome.cube.dev/tools/material-ui-data-grid) | [React data table with Material UI](https://dev.to/cubejs/react-data-table-with-material-ui-and-a-spark-of-joy-50o1)     | [Demo](https://react-data-table-demo.cube.dev)                                          |
| 📈 [Material](https://material.io)                                     | [Angular dashboard with Material](https://angular-dashboard.cube.dev)                                                    | [Demo](https://angular-dashboard-demo.cube.dev)                                         |
| 📊 [AG Grid](https://awesome.cube.dev/tools/ag-grid)                   | [React Pivot Table with AG Grid](https://react-pivot-table.cube.dev)                                                     | [Demo](https://react-pivot-table-demo.cube.dev)                                         |
| 🗺 [Mapbox](https://awesome.cube.dev/tools/mapbox-gl)                  | [Building map-based data visualizations with Mapbox](https://mapbox-guide.cube.dev)                                      | [Demo](https://mapbox-demo.cube.dev)                                                    |
| 📊 [Retool](https://retool.com/)                                       | [Building an internal dashboard with Retool](https://cube.dev/blog/building-an-internal-dashboard-with-retool-and-cube/) | [Demo](https://cubedev.retool.com/embedded/public/945c174d-566e-42f6-b33c-73052847e483) |

### <--{"id" : "Tutorials"}--> Demo applications

Have a look at some demo applications you can build with Cube.js:

| Application                                          | Story                                                                                                                          |
| :--------------------------------------------------- | :----------------------------------------------------------------------------------------------------------------------------- |
| [Hacktoberfest 2020](https://hacktoberfest.cube.dev) | [Hacktoberfest 2020 in insights and statistics](https://dev.to/igorlukanin/hacktoberfest-2020-in-insights-and-statistics-3m57) |

Cube integrates with all kinds of [data sources](https://cube.dev/docs/config/databases) and data [visualization tools](https://cube.dev/docs/config/downstream). You can [find](https://cube.dev/for) more easy-step guides to get started with Cube.
